@@ -1,8 +1,12 @@
-from dagster_graphql.implementation.utils import ExecutionMetadata, ExecutionParams
-
 from dagster import EventMetadataEntry, check, seven
-from dagster.core.definitions import ExpectationResult, Materialization, SolidHandle
+from dagster.core.definitions import (
+    AssetMaterialization,
+    ExpectationResult,
+    Materialization,
+    SolidHandle,
+)
 from dagster.core.definitions.events import PythonArtifactMetadataEntryData
+from dagster.core.definitions.reconstructable import ReconstructableRepository
 from dagster.core.events import (
     DagsterEvent,
     DagsterEventType,
@@ -20,8 +24,6 @@ from dagster.core.execution.plan.objects import (
     TypeCheckData,
     UserFailureData,
 )
-from dagster.core.storage.pipeline_run import PipelineRun, PipelineRunStatus
-from dagster.core.utils import make_new_run_id
 from dagster.utils.error import SerializableErrorInfo
 
 HANDLED_EVENTS = {
@@ -50,6 +52,12 @@ def expectation_result_from_data(data):
 
 
 def materialization_from_data(data):
+    if data.get('asset_key'):
+        return AssetMaterialization(
+            asset_key=data['asset_key'],
+            description=data.get('description'),
+            metadata_entries=list(event_metadata_entries(data.get('metadataEntries')) or []),
+        )
     return Materialization(
         label=data['label'],
         description=data.get('description'),  # enforce?
@@ -121,9 +129,7 @@ def dagster_event_from_dict(event_dict, pipeline_name):
     event_specific_data = None
     if event_type == DagsterEventType.STEP_OUTPUT:
         event_specific_data = StepOutputData(
-            step_output_handle=StepOutputHandle(
-                event_dict['step']['key'], event_dict['outputName']
-            ),
+            step_output_handle=StepOutputHandle(event_dict['stepKey'], event_dict['outputName']),
             type_check_data=TypeCheckData(
                 success=event_dict['typeCheck']['success'],
                 label=event_dict['typeCheck']['label'],
@@ -188,55 +194,90 @@ def dagster_event_from_dict(event_dict, pipeline_name):
             else None,
         )
 
-    # We should update the GraphQL response so that clients don't need to do this handle parsing.
-    # See: https://github.com/dagster-io/dagster/issues/1559
-    handle = None
-    step_key = None
-    step_kind_value = None
-    if 'step' in event_dict and event_dict['step']:
-        step_key = event_dict['step']['key']
-        step_kind_value = event_dict['step']['kind']
-        keys = event_dict['step']['solidHandleID'].split('.')
-        while keys:
-            handle = SolidHandle(keys.pop(0), definition_name=None, parent=handle)
-
     return DagsterEvent(
         event_type_value=event_type.value,
         pipeline_name=pipeline_name,
-        step_key=step_key,
-        solid_handle=handle,
-        step_kind_value=step_kind_value,
+        step_key=event_dict.get('stepKey'),
+        solid_handle=SolidHandle.from_string(event_dict['solidHandleID'])
+        if event_dict.get('solidHandleID')
+        else None,
+        # at the time of writing this:
+        # * 'COMPUTE` is the only step kind
+        # * this code should get deleted in the near future as we move away from
+        #   dagster-graphql CLI as what we invoke in dask/k8s/etc.
+        step_kind_value='COMPUTE' if event_dict.get('stepKey') else None,
         logging_tags=None,
         event_specific_data=event_specific_data,
     )
 
 
-def pipeline_run_from_execution_params(execution_params, step_keys_to_execute=None):
-    check.inst_param(execution_params, 'execution_params', ExecutionParams)
+def construct_execute_plan_variables(
+    recon_repo, mode, run_config, pipeline_name, run_id, step_keys
+):
+    check.inst_param(recon_repo, 'recon_repo', ReconstructableRepository)
+    check.str_param(mode, 'mode')
+    check.dict_param(run_config, 'run_config')
+    check.str_param(pipeline_name, 'pipeline_name')
+    check.str_param(run_id, 'run_id')
+    check.list_param(step_keys, 'step_keys', of_type=str)
 
-    return PipelineRun(
-        pipeline_name=execution_params.selector.name,
-        run_id=execution_params.execution_metadata.run_id
-        if execution_params.execution_metadata.run_id
-        else make_new_run_id(),
-        selector=execution_params.selector,
-        environment_dict=execution_params.environment_dict,
-        mode=execution_params.mode,
-        step_keys_to_execute=step_keys_to_execute or execution_params.step_keys,
-        tags=execution_params.execution_metadata.tags,
-        status=PipelineRunStatus.NOT_STARTED,
-        previous_run_id=execution_params.previous_run_id,
-    )
+    variables = {
+        'executionParams': {
+            'runConfigData': run_config,
+            'mode': mode,
+            'selector': {
+                'repositoryLocationName': '<<in_process>>',
+                'repositoryName': recon_repo.get_definition().name,
+                'pipelineName': pipeline_name,
+            },
+            'executionMetadata': {'runId': run_id},
+            'stepKeys': step_keys,
+        },
+    }
+
+    return variables
 
 
-def execution_params_from_pipeline_run(run):
-    check.inst_param(run, 'run', PipelineRun)
+def parse_raw_log_lines(log_lines):
+    '''Parses the raw log lines response from a dagster-graphql CLI invocation, typically from a
+    Docker or Kubernetes container.
 
-    return ExecutionParams(
-        mode=run.mode,
-        step_keys=run.step_keys_to_execute,
-        environment_dict=run.environment_dict,
-        selector=run.selector,
-        execution_metadata=ExecutionMetadata(run_id=run.run_id, tags=run.tags),
-        previous_run_id=run.previous_run_id,
-    )
+     - Log lines don't necessarily come back in order
+     - Something else might log JSON
+     - Docker appears to silently split very long log lines -- this is undocumented behavior
+
+    Args:
+        log_lines (List[str]): Log lines containing response JSON
+
+    Returns:
+        Dict: Parsed JSON response
+    '''
+    res = None
+    lines = []
+    coalesced = []
+    in_split_line = False
+    for line in log_lines:
+        if not in_split_line and line.startswith('{'):
+            if line.endswith('}'):
+                lines.append(line)
+                continue
+            else:
+                coalesced.append(line)
+                in_split_line = True
+                continue
+        if in_split_line:
+            coalesced.append(line)
+            if line.endswith('}'):
+                lines.append(''.join(coalesced))
+                coalesced = []
+                in_split_line = False
+
+    for line in reversed(lines):
+        try:
+            res = seven.json.loads(line)
+            break
+        # If we don't get a GraphQL response, check the next line
+        except seven.JSONDecodeError:
+            continue
+
+    return res
