@@ -3,12 +3,13 @@ from dagster_graphql.client.mutations import (
     execute_execute_plan_mutation_raw,
 )
 
-from dagster import ExecutionTargetHandle
+from dagster import file_relative_path
+from dagster.cli.workspace.cli_target import PythonFileTarget, workspace_from_load_target
+from dagster.core.definitions.reconstructable import ReconstructablePipeline
+from dagster.core.host_representation import UserProcessApi
 from dagster.core.instance import DagsterInstance
-from dagster.core.utils import make_new_run_id
 
 EXPECTED_EVENTS = {
-    ('ENGINE_EVENT', None),
     ('STEP_INPUT', 'sleeper.compute'),
     ('STEP_INPUT', 'sleeper_2.compute'),
     ('STEP_INPUT', 'sleeper_3.compute'),
@@ -35,24 +36,40 @@ EXPECTED_EVENTS = {
 }
 
 
+def load_sleepy_workspace():
+    return workspace_from_load_target(
+        PythonFileTarget(
+            file_relative_path(__file__, 'sleepy.py'), 'sleepy_pipeline', UserProcessApi.CLI
+        )
+    )
+
+
+def sleepy_recon_pipeline():
+    return ReconstructablePipeline.for_file(
+        file_relative_path(__file__, 'sleepy.py'), 'sleepy_pipeline'
+    )
+
+
 def test_execute_execute_plan_mutation():
     pipeline_name = 'sleepy_pipeline'
-    handle = ExecutionTargetHandle.for_pipeline_module(
-        'dagster_examples.toys.sleepy', pipeline_name
-    )
-    run_id = make_new_run_id()
-    instance = DagsterInstance.local_temp()
-    instance.create_empty_run(run_id, pipeline_name)
 
+    pipeline = sleepy_recon_pipeline()
+    workspace = load_sleepy_workspace()
+    instance = DagsterInstance.local_temp()
+    pipeline_run = instance.create_run_for_pipeline(pipeline_def=pipeline.get_definition())
     variables = {
         'executionParams': {
-            'environmentConfigData': {},
+            'runConfigData': {},
             'mode': 'default',
-            'selector': {'name': pipeline_name},
-            'executionMetadata': {'runId': run_id},
+            'selector': {
+                'repositoryLocationName': pipeline_name,
+                'repositoryName': '<<unnamed>>',
+                'pipelineName': pipeline_name,
+            },
+            'executionMetadata': {'runId': pipeline_run.run_id},
         }
     }
-    result = execute_execute_plan_mutation(handle, variables, instance_ref=instance.get_ref())
+    result = execute_execute_plan_mutation(workspace, variables, instance_ref=instance.get_ref())
     seen_events = set()
     for event in result:
         seen_events.add((event.event_type_value, event.step_key))
@@ -62,45 +79,28 @@ def test_execute_execute_plan_mutation():
 
 def test_execute_execute_plan_mutation_raw():
     pipeline_name = 'sleepy_pipeline'
-    handle = ExecutionTargetHandle.for_pipeline_module(
-        'dagster_examples.toys.sleepy', pipeline_name
-    )
-    run_id = make_new_run_id()
+    pipeline = sleepy_recon_pipeline()
+    workspace = load_sleepy_workspace()
+
     instance = DagsterInstance.local_temp()
-    instance.create_empty_run(run_id, pipeline_name)
+    pipeline_run = instance.create_run_for_pipeline(pipeline_def=pipeline.get_definition())
     variables = {
         'executionParams': {
-            'environmentConfigData': {},
+            'runConfigData': {},
             'mode': 'default',
-            'selector': {'name': pipeline_name},
-            'executionMetadata': {'runId': run_id},
+            'selector': {
+                'repositoryLocationName': pipeline_name,
+                'repositoryName': '<<unnamed>>',
+                'pipelineName': pipeline_name,
+            },
+            'executionMetadata': {'runId': pipeline_run.run_id},
         }
     }
-    result = execute_execute_plan_mutation_raw(handle, variables, instance_ref=instance.get_ref())
+    result = execute_execute_plan_mutation_raw(
+        workspace, variables, instance_ref=instance.get_ref()
+    )
     seen_events = set()
     for event in result:
         seen_events.add((event.dagster_event.event_type_value, event.step_key))
 
     assert seen_events == EXPECTED_EVENTS
-
-
-# TODO: uncomment when resolving https://github.com/dagster-io/dagster/issues/1876
-# def test_execute_plan_for_unknown_run():
-#     pipeline_name = 'sleepy_pipeline'
-#     handle = ExecutionTargetHandle.for_pipeline_module(
-#         'dagster_examples.toys.sleepy', pipeline_name
-#     )
-#     unknown_run_id = '12345'
-#     variables = {
-#         'executionParams': {
-#             'environmentConfigData': {},
-#             'mode': 'default',
-#             'selector': {'name': pipeline_name},
-#             'executionMetadata': {'runId': unknown_run_id},
-#         }
-#     }
-#     with pytest.raises(DagsterGraphQLClientError) as exc_info:
-#         execute_execute_plan_mutation_raw(handle, variables)
-#     assert str(exc_info.value) == 'Pipeline run {run_id} could not be found.'.format(
-#         run_id=unknown_run_id
-#     )
